# dotenv-vault-python

dotenv-vault-python allows your app to sync the `.env` file to the cloud. This means that you can work anywhere, in any machine, and in any cloud infrastructure with cofidence.

## Getting Started


## Getting Started
pip install twine
python setup.py sdist

twine upload dist/*